@@ -34,7 +34,7 @@ def get_request_parms():
     return (urlparse.parse_qs(web.ctx.query[1:], True), body)
 
 
-def get_json(func):
+def json_response(func):
     """ Translates results of 'func' into a JSON request. """
     def wrap(*a, **kw):
         if web.ctx.path[-1] != '/':
@@ -51,17 +51,3 @@ def get_json(func):
         web.header('Content-Type', 'application/json; charset=utf-8')
         return results
     return wrap
-
-
-class JsonHandler(object):
-    """
-    Deprecated; use decorators instead, allowing for mixed response types.
-    """
-
-    @get_json
-    def GET(self):
-        args, body = get_request_parms()
-        return self._GET(args, body)
-
-    def _GET(self, params, body):
-        raise NotImplementedError
